// Set the dimensions and margins of the graph
const margin = { top: 20, right: 30, bottom: 30, left: 50 },
  width = 960 - margin.left - margin.right,
  height = 500 - margin.top - margin.bottom;

// Append the svg object to the body of the page
const svg = d3
  .select('svg')
  .attr('width', width + margin.left + margin.right)
  .attr('height', height + margin.top + margin.bottom)
  .append('g')
  .attr(
    'transform',
    'translate(' + margin.left + ',' + margin.top + ')',
  );

// Parse the Date / time
const parseDate = d3.timeParse('%Y-%m-%d');

// Set the ranges
const x = d3.scaleTime().range([0, width]);
const y = d3.scaleLinear().range([height, 0]);

// Define the area
const area = d3
  .area()
  .x(function (d) {
    return x(d.date);
  })
  .y0(height)
  .y1(function (d) {
    return y(d.visitors);
  });

// Get the data
d3.csv(
  'https://gist.githubusercontent.com/Sannihitha23/eea0764694dc229ff954c35332d1673e/raw/3831bd6d793f39b9282eb3b257bdbf6271d4d4a4/web_traffic.csv',
  function (d) {
    d.date = parseDate(d.Date);
    d.visitors = +d.Visitors;
    return d;
  },
).then(function (data) {
  // Scale the range of the data
  x.domain(
    d3.extent(data, function (d) {
      return d.date;
    }),
  );
  y.domain([
    0,
    d3.max(data, function (d) {
      return d.visitors;
    }),
  ]);

  // Add the valueline path.
  svg
    .append('path')
    .data([data])
    .attr('class', 'area')
    .attr('d', area);

  // Add the X Axis
  svg
    .append('g')
    .attr('transform', 'translate(0,' + height + ')')
    .call(d3.axisBottom(x));

  // Add the Y Axis
  svg.append('g').call(d3.axisLeft(y));

  // Add X-axis label
  svg
    .append('text')
    .attr('text-anchor', 'end')
    .attr('x', width / 2)
    .attr('y', height + margin.bottom - 5)
    .text('Date');

  // Add Y-axis label
  svg
    .append('text')
    .attr('text-anchor', 'end')
    .attr('transform', 'rotate(-90)')
    .attr('y', -margin.left + 20)
    .attr('x', -height / 2)
    .text('Number of Visitors');
});
